.. -*- coding: utf-8 -*-

.. _ifabp-water:

================
 I-FABP dataset
================

.. module:: MDAnalysisData.ifabp_water

The :mod:`MDAnalysisData.ifabp_water` module contains a short
equilibrium MD trajectory of the globular protein intestinal fatty
acid binding protein (I-FABP) with all the solvent included (water and
ions).  It can be used to study protein dynamics, protein-ion, and
protein-water interactions.

.. currentmodule:: MDAnalysisData.ifabp_water

.. autosummary::

   fetch_ifabp_water


.. include:: ../MDAnalysisData/descr/ifabp_water.rst

.. autofunction:: fetch_ifabp_water

		  
